Updates
=======


Version 0.1.4
-------------

- **Added MANIFEST.in** to allow uploading images, docs, ... via PyPi

Version 0.1.3
-------------

- **New executable for mac OS**

- **preciso.version()** added.

- **preciso.add_logo** refactored and docstring cleaned up.

